@@ -60,24 +60,24 @@ fi
 
 cd /tmp/ || die "Can't chdir to /tmp/ ."
 
-if [ ! -r kernel-source-2.6.34.10-0.6.1.src.rpm ]
+if [ ! -r kernel-source-2.6.34.7-0.5.1.src.rpm ]
 then
-    wget http://download.opensuse.org/update/11.3/rpm/src/kernel-source-2.6.34.10-0.6.1.src.rpm || die "Can't download source package."
+    wget http://download.opensuse.org/update/11.3/rpm/src/kernel-source-2.6.34.7-0.5.1.src.rpm || die "Can't download source package."
 fi
-rpm --checksig kernel-source-2.6.34.10-0.6.1.src.rpm || die "Can't verify signature."
-rpm -ivh kernel-source-2.6.34.10-0.6.1.src.rpm || die "Can't install source package."
+rpm --checksig kernel-source-2.6.34.7-0.5.1.src.rpm || die "Can't verify signature."
+rpm -ivh kernel-source-2.6.34.7-0.5.1.src.rpm || die "Can't install source package."
 
-if [ ! -r kernel-default-2.6.34.10-0.6.1.nosrc.rpm ]
+if [ ! -r kernel-default-2.6.34.7-0.5.1.nosrc.rpm ]
 then
-    wget http://download.opensuse.org/update/11.3/rpm/src/kernel-default-2.6.34.10-0.6.1.nosrc.rpm || die "Can't download source package."
+    wget http://download.opensuse.org/update/11.3/rpm/src/kernel-default-2.6.34.7-0.5.1.nosrc.rpm || die "Can't download source package."
 fi
-rpm --checksig kernel-default-2.6.34.10-0.6.1.nosrc.rpm || die "Can't verify signature."
-rpm -ivh kernel-default-2.6.34.10-0.6.1.nosrc.rpm || die "Can't install source package."
+rpm --checksig kernel-default-2.6.34.7-0.5.1.nosrc.rpm || die "Can't verify signature."
+rpm -ivh kernel-default-2.6.34.7-0.5.1.nosrc.rpm || die "Can't install source package."
 
 cd /usr/src/packages/SOURCES/ || die "Can't chdir to /usr/src/packages/SOURCES/ ."
-if [ ! -r ccs-patch-1.7.3-20120819.tar.gz ]
+if [ ! -r ccs-patch-1.8.0-20101111.tar.gz ]
 then
-    wget -O ccs-patch-1.7.3-20120819.tar.gz 'http://sourceforge.jp/frs/redir.php?f=/tomoyo/43375/ccs-patch-1.7.3-20120819.tar.gz' || die "Can't download patch."
+    wget http://sourceforge.jp/frs/redir.php?f=/tomoyo/49684/ccs-patch-1.8.0-20101111.tar.gz || die "Can't download patch."
 fi
 
 cd /tmp/ || die "Can't chdir to /tmp/ ."
@@ -92,9 +92,9 @@ patch << "EOF" || die "Can't patch spec file."
 -Name:           kernel-default
 +Name:           ccs-kernel-default
  Summary:        The Standard Kernel
- Version:        2.6.34.10
--Release:        0.6.1
-+Release:        0.6.1_tomoyo_1.7.3p4
+ Version:        2.6.34.7
+-Release:        0.5.1
++Release:        0.5.1_tomoyo_1.8.0
  %if %using_buildservice
  %else
  %endif
@@ -103,7 +103,7 @@ patch << "EOF" || die "Can't patch spec file."
  	%_sourcedir/series.conf .. $SYMBOLS
  
 +# TOMOYO Linux
-+tar -zxf %_sourcedir/ccs-patch-1.7.3-20120819.tar.gz
++tar -zxf %_sourcedir/ccs-patch-1.8.0-20101111.tar.gz
 +patch -sp1 < patches/ccs-patch-2.6.34-suse-11.3.diff
 +cat config.ccs >> ../config/%cpu_arch_flavor
 +
@@ -111,7 +111,6 @@ patch << "EOF" || die "Can't patch spec file."
  
  if [ -f %_sourcedir/localversion ] ; then
 EOF
-touch /usr/src/packages/SOURCES/IGNORE-KABI-BADNESS
 sed -e 's:^Provides:#Provides:' -e 's:^Obsoletes:#Obsoletes:' -e 's:-n kernel:-n ccs-kernel:' kernel-default.spec > ccs-kernel.spec || die "Can't edit spec file."
 echo ""
 echo ""
@@ -120,7 +119,8 @@ echo "Edit /tmp/ccs-kernel.spec if needed, and run"
 echo "rpmbuild -bb /tmp/ccs-kernel.spec"
 echo "to build kernel rpm packages."
 echo ""
-echo "I'll start 'rpmbuild -bb --target i586 /tmp/ccs-kernel.spec' in 30 seconds. Press Ctrl-C to stop."
+ARCH=`uname -m`
+echo "I'll start 'rpmbuild -bb --target $ARCH /tmp/ccs-kernel.spec' in 30 seconds. Press Ctrl-C to stop."
 sleep 30
-exec rpmbuild -bb --target i586 /tmp/ccs-kernel.spec
+exec rpmbuild -bb --target $ARCH /tmp/ccs-kernel.spec
 exit 0
