@@ -1,6 +1,6 @@
 #! /bin/sh
 #
-# This is a kernel build script for VineLinux 5.2's 2.6.27 kernel.
+# This is a kernel build script for VineLinux 4.2's 2.6.16 kernel.
 #
 
 die () {
@@ -10,17 +10,17 @@ die () {
 
 cd /tmp/ || die "Can't chdir to /tmp/ ."
 
-if [ ! -r kernel-2.6.27-76vl5.src.rpm ]
+if [ ! -r kernel-2.6.16-76.55vl4.src.rpm ]
 then
-    wget http://updates.vinelinux.org/Vine-5.2/updates/SRPMS/kernel-2.6.27-76vl5.src.rpm || die "Can't download source package."
+    wget http://updates.vinelinux.org/Vine-4.2/updates/SRPMS/kernel-2.6.16-76.55vl4.src.rpm || die "Can't download source package."
 fi
-rpm --checksig kernel-2.6.27-76vl5.src.rpm || die "Can't verify signature."
-rpm -ivh kernel-2.6.27-76vl5.src.rpm || die "Can't install source package."
+rpm --checksig kernel-2.6.16-76.55vl4.src.rpm || die "Can't verify signature."
+rpm -ivh kernel-2.6.16-76.55vl4.src.rpm || die "Can't install source package."
 
 cd /usr/src/vine/SOURCES/ || die "Can't chdir to /usr/src/vine/SOURCES/ ."
-if [ ! -r ccs-patch-1.7.3-20120819.tar.gz ]
+if [ ! -r ccs-patch-1.8.0-20101111.tar.gz ]
 then
-    wget -O ccs-patch-1.7.3-20120819.tar.gz 'http://sourceforge.jp/frs/redir.php?f=/tomoyo/43375/ccs-patch-1.7.3-20120819.tar.gz' || die "Can't download patch."
+    wget -O ccs-patch-1.8.0-20101111.tar.gz 'http://sourceforge.jp/frs/redir.php?f=/tomoyo/49684/ccs-patch-1.8.0-20101111.tar.gz' || die "Can't download patch."
 fi
 
 cd /tmp/ || die "Can't chdir to /tmp/ ."
@@ -28,16 +28,16 @@ cp -p /usr/src/vine/SPECS/kernel-2.6-vl.spec . || die "Can't copy spec file."
 patch << "EOF" || die "Can't patch spec file."
 --- kernel-2.6-vl.spec
 +++ kernel-2.6-vl.spec
-@@ -27,7 +27,7 @@
- %define patchlevel 62
+@@ -23,7 +23,7 @@
+ %define sublevel 16
  %define kversion 2.6.%{sublevel}
  %define rpmversion 2.6.%{sublevel}
--%define release 76%{?_dist_release}
-+%define release 76%{?_dist_release}_tomoyo_1.7.3p4
+-%define release 76.55%{_dist_release}
++%define release 76.55%{_dist_release}_tomoyo_1.8.0
  
  %define make_target bzImage
- %define hdrarch %_target_cpu
-@@ -121,6 +121,9 @@
+ 
+@@ -100,6 +100,9 @@
  # to versions below the minimum
  #
  
@@ -47,27 +47,27 @@ patch << "EOF" || die "Can't patch spec file."
  #
  # First the general kernel 2.6 required versions as per
  # Documentation/Changes
-@@ -153,7 +156,7 @@
+@@ -126,7 +129,7 @@
  #
- %define kernel_prereq  fileutils, module-init-tools >= 3.6, initscripts >= 8.80, mkinitrd >= 5.1.19.6, kernel-firmware >= %{version}
+ %define kernel_prereq  fileutils, modutils >= 3.2.2 , initscripts >= 5.83, mkinitrd >= 4.2.1.8-0vl2.1
  
 -Name: kernel
 +Name: ccs-kernel
  Group: System Environment/Kernel
  License: GPLv2
  Version: %{rpmversion}
-@@ -848,6 +851,10 @@
+@@ -1155,6 +1158,10 @@
  
  # END OF PATCH APPLICATIONS
  
 +# TOMOYO Linux
-+tar -zxf %_sourcedir/ccs-patch-1.7.3-20120819.tar.gz
-+patch -sp1 < patches/ccs-patch-2.6.27-vine-linux-5.2.diff
++tar -zxf %_sourcedir/ccs-patch-1.8.0-20101111.tar.gz
++patch -sp1 < patches/ccs-patch-2.6.16-vine-linux-4.2.diff
 +
  cp %{SOURCE10} Documentation/
  
  # put Vine logo
-@@ -866,6 +873,9 @@
+@@ -1175,6 +1182,9 @@
  for i in *.config
  do 
  	mv $i .config 
@@ -86,7 +86,8 @@ echo "Edit /tmp/ccs-kernel.spec if needed, and run"
 echo "rpmbuild -bb /tmp/ccs-kernel.spec"
 echo "to build kernel rpm packages."
 echo ""
-echo "I'll start 'rpmbuild -bb --target i586 /tmp/ccs-kernel.spec' in 30 seconds. Press Ctrl-C to stop."
+ARCH=`uname -m`
+echo "I'll start 'rpmbuild -bb --target $ARCH /tmp/ccs-kernel.spec' in 30 seconds. Press Ctrl-C to stop."
 sleep 30
-exec rpmbuild -bb --target i586 /tmp/ccs-kernel.spec
+exec rpmbuild -bb --target $ARCH /tmp/ccs-kernel.spec
 exit 0
